==> 1.1.7.tar.gz: t2code-alias/src/main/java/net/t2code/alias/Spigot/config/config/SelectConfig.java <==
package net.t2code.alias.Spigot.config.config;

import net.t2code.alias.Spigot.Main;
import net.t2code.t2codelib.SPIGOT.api.yaml.T2Cconfig;
import org.bukkit.configuration.file.YamlConfiguration;

import java.io.File;
import java.io.IOException;

public class SelectConfig {
    private static Integer ConfigVersion = 3;
    private static Integer isConfigVersion;
    private static Boolean updateCheckOnJoin;
    private static Boolean updateCheckSeePreReleaseUpdates;
    private static Integer updateCheckTimeInterval;
    private static String language;
    private static Boolean Bungee;
    private static String thisServer;

    private static Boolean buyMessage;
    private static Boolean subAliasTab;

    public static void onSelect() {
        File config = new File(Main.getPath(), "config.yml");
        YamlConfiguration yamlConfiguration = YamlConfiguration.loadConfiguration(config);

        isConfigVersion = yamlConfiguration.getInt("ConfigVersion");

        updateCheckOnJoin = yamlConfiguration.getBoolean("Plugin.updateCheck.onJoin");
        updateCheckSeePreReleaseUpdates = yamlConfiguration.getBoolean("Plugin.updateCheck.seePreReleaseUpdates");
        updateCheckTimeInterval = yamlConfiguration.getInt("Plugin.updateCheck.timeInterval");


        language = yamlConfiguration.getString("Plugin.language");
        Bungee = yamlConfiguration.getBoolean("BungeeCord.Enable");
        thisServer = yamlConfiguration.getString("BungeeCord.ThisServer");

        buyMessage = yamlConfiguration.getBoolean("Buy.Message");
        subAliasTab = yamlConfiguration.getBoolean("SubAlias.TabComplete");
    }
    public static void setConfigVersion() {
        File config = new File(Main.getPath(), "config.yml");
        YamlConfiguration yamlConfiguration = YamlConfiguration.loadConfiguration(config);
        yamlConfiguration.set("ConfigVersion", ConfigVersion);
        try {
            yamlConfiguration.save(config);
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    public static Integer getConfigVersion() {
        return ConfigVersion;
    }

    public static Integer getIsConfigVersion() {
        return isConfigVersion;
    }

    public static Boolean getUpdateCheckOnJoin() {
        return updateCheckOnJoin;
    }

    public static Boolean getUpdateCheckSeePreReleaseUpdates() {
        return updateCheckSeePreReleaseUpdates;
    }

    public static Integer getUpdateCheckTimeInterval() {
        return updateCheckTimeInterval;
    }

    public static String getLanguage() {
        return language;
    }

    public static Boolean getBungee() {
        return Bungee;
    }

    public static String getThisServer() {
        return thisServer;
    }

    public static Boolean getBuyMessage() {
        return buyMessage;
    }

    public static Boolean getSubAliasTab() {
        return subAliasTab;
    }
}

==> 1.2.1.tar.gz: t2code-alias/src/main/java/net/t2code/alias/Spigot/config/config/SelectConfig.java <==
package net.t2code.alias.Spigot.config.config;

import net.t2code.alias.Spigot.Main;
import net.t2code.t2codelib.SPIGOT.api.yaml.T2Cconfig;
import org.bukkit.configuration.file.YamlConfiguration;

import java.io.File;
import java.io.IOException;

public class SelectConfig {
    private static Integer ConfigVersion = 3;
    private static Integer isConfigVersion;
    private static Boolean updateCheckOnJoin;
    private static Boolean updateCheckSeePreReleaseUpdates;
    private static Integer updateCheckTimeInterval;
    private static String language;

    private static Boolean buyMessage;
    private static String buyCurrency;
    private static Boolean subAliasTab;

    public static void onSelect() {
        File config = new File(Main.getPath(), "config.yml");
        YamlConfiguration yamlConfiguration = YamlConfiguration.loadConfiguration(config);

        isConfigVersion = yamlConfiguration.getInt("ConfigVersion");

        updateCheckOnJoin = yamlConfiguration.getBoolean("plugin.updateCheck.onJoin");
        updateCheckSeePreReleaseUpdates = yamlConfiguration.getBoolean("plugin.updateCheck.seePreReleaseUpdates");
        updateCheckTimeInterval = yamlConfiguration.getInt("plugin.updateCheck.timeInterval");

        language = yamlConfiguration.getString("plugin.language");

        buyMessage = yamlConfiguration.getBoolean("buy.message");
        buyCurrency = yamlConfiguration.getString("buy.currency");
        subAliasTab = yamlConfiguration.getBoolean("subAlias.tabComplete");
    }
    public static void setConfigVersion() {
        File config = new File(Main.getPath(), "config.yml");
        YamlConfiguration yamlConfiguration = YamlConfiguration.loadConfiguration(config);
        yamlConfiguration.set("ConfigVersion", ConfigVersion);
        try {
            yamlConfiguration.save(config);
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    public static Integer getConfigVersion() {
        return ConfigVersion;
    }

    public static Integer getIsConfigVersion() {
        return isConfigVersion;
    }

    public static Boolean getUpdateCheckOnJoin() {
        return updateCheckOnJoin;
    }

    public static Boolean getUpdateCheckSeePreReleaseUpdates() {
        return updateCheckSeePreReleaseUpdates;
    }

    public static Integer getUpdateCheckTimeInterval() {
        return updateCheckTimeInterval;
    }

    public static String getLanguage() {
        return language;
    }


    public static Boolean getBuyMessage() {
        return buyMessage;
    }

    public static String getBuyCurrency() {
        return buyCurrency;
    }

    public static Boolean getSubAliasTab() {
        return subAliasTab;
    }
}
